# audiofile benchmarks


## Installation

Install all system dependencies on Ubuntu,
create virtual environment
and install Python packages:

```bash
$ bash install_dependencies.sh
```

## Usage

First generate the needed audio data:

```bash
$ bash generate_audio.sh
```

Execute the benchmarks with:

```bash
$ bash run.sh
```
